@@ -17,7 +17,7 @@ from collections import OrderedDict
 from distutils import util
 import os
 import re
-from typing import Callable, Dict, Optional, Sequence, Tuple, Type, Union
+from typing import Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core import client_options as client_options_lib  # type: ignore
@@ -435,11 +435,12 @@ class AutoMlClient(metaclass=AutoMlClientMeta):
                 client_cert_source_for_mtls=client_cert_source_func,
                 quota_project_id=client_options.quota_project_id,
                 client_info=client_info,
+                always_use_jwt_access=True,
             )
 
     def create_dataset(
         self,
-        request: service.CreateDatasetRequest = None,
+        request: Union[service.CreateDatasetRequest, dict] = None,
         *,
         parent: str = None,
         dataset: gca_dataset.Dataset = None,
@@ -450,7 +451,7 @@ class AutoMlClient(metaclass=AutoMlClientMeta):
         r"""Creates a dataset.
 
         Args:
-            request (google.cloud.automl_v1.types.CreateDatasetRequest):
+            request (Union[google.cloud.automl_v1.types.CreateDatasetRequest, dict]):
                 The request object. Request message for
                 [AutoMl.CreateDataset][google.cloud.automl.v1.AutoMl.CreateDataset].
             parent (str):
@@ -528,7 +529,7 @@ class AutoMlClient(metaclass=AutoMlClientMeta):
 
     def get_dataset(
         self,
-        request: service.GetDatasetRequest = None,
+        request: Union[service.GetDatasetRequest, dict] = None,
         *,
         name: str = None,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
@@ -538,7 +539,7 @@ class AutoMlClient(metaclass=AutoMlClientMeta):
         r"""Gets a dataset.
 
         Args:
-            request (google.cloud.automl_v1.types.GetDatasetRequest):
+            request (Union[google.cloud.automl_v1.types.GetDatasetRequest, dict]):
                 The request object. Request message for
                 [AutoMl.GetDataset][google.cloud.automl.v1.AutoMl.GetDataset].
             name (str):
@@ -601,7 +602,7 @@ class AutoMlClient(metaclass=AutoMlClientMeta):
 
     def list_datasets(
         self,
-        request: service.ListDatasetsRequest = None,
+        request: Union[service.ListDatasetsRequest, dict] = None,
         *,
         parent: str = None,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
@@ -611,7 +612,7 @@ class AutoMlClient(metaclass=AutoMlClientMeta):
         r"""Lists datasets in a project.
 
         Args:
-            request (google.cloud.automl_v1.types.ListDatasetsRequest):
+            request (Union[google.cloud.automl_v1.types.ListDatasetsRequest, dict]):
                 The request object. Request message for
                 [AutoMl.ListDatasets][google.cloud.automl.v1.AutoMl.ListDatasets].
             parent (str):
@@ -681,7 +682,7 @@ class AutoMlClient(metaclass=AutoMlClientMeta):
 
     def update_dataset(
         self,
-        request: service.UpdateDatasetRequest = None,
+        request: Union[service.UpdateDatasetRequest, dict] = None,
         *,
         dataset: gca_dataset.Dataset = None,
         update_mask: field_mask_pb2.FieldMask = None,
@@ -692,7 +693,7 @@ class AutoMlClient(metaclass=AutoMlClientMeta):
         r"""Updates a dataset.
 
         Args:
-            request (google.cloud.automl_v1.types.UpdateDatasetRequest):
+            request (Union[google.cloud.automl_v1.types.UpdateDatasetRequest, dict]):
                 The request object. Request message for
                 [AutoMl.UpdateDataset][google.cloud.automl.v1.AutoMl.UpdateDataset]
             dataset (google.cloud.automl_v1.types.Dataset):
@@ -766,7 +767,7 @@ class AutoMlClient(metaclass=AutoMlClientMeta):
 
     def delete_dataset(
         self,
-        request: service.DeleteDatasetRequest = None,
+        request: Union[service.DeleteDatasetRequest, dict] = None,
         *,
         name: str = None,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
@@ -780,7 +781,7 @@ class AutoMlClient(metaclass=AutoMlClientMeta):
         [metadata][google.longrunning.Operation.metadata] field.
 
         Args:
-            request (google.cloud.automl_v1.types.DeleteDatasetRequest):
+            request (Union[google.cloud.automl_v1.types.DeleteDatasetRequest, dict]):
                 The request object. Request message for
                 [AutoMl.DeleteDataset][google.cloud.automl.v1.AutoMl.DeleteDataset].
             name (str):
@@ -862,7 +863,7 @@ class AutoMlClient(metaclass=AutoMlClientMeta):
 
     def import_data(
         self,
-        request: service.ImportDataRequest = None,
+        request: Union[service.ImportDataRequest, dict] = None,
         *,
         name: str = None,
         input_config: io.InputConfig = None,
@@ -882,7 +883,7 @@ class AutoMlClient(metaclass=AutoMlClientMeta):
            field when it completes.
 
         Args:
-            request (google.cloud.automl_v1.types.ImportDataRequest):
+            request (Union[google.cloud.automl_v1.types.ImportDataRequest, dict]):
                 The request object. Request message for
                 [AutoMl.ImportData][google.cloud.automl.v1.AutoMl.ImportData].
             name (str):
@@ -975,7 +976,7 @@ class AutoMlClient(metaclass=AutoMlClientMeta):
 
     def export_data(
         self,
-        request: service.ExportDataRequest = None,
+        request: Union[service.ExportDataRequest, dict] = None,
         *,
         name: str = None,
         output_config: io.OutputConfig = None,
@@ -989,7 +990,7 @@ class AutoMlClient(metaclass=AutoMlClientMeta):
         completes.
 
         Args:
-            request (google.cloud.automl_v1.types.ExportDataRequest):
+            request (Union[google.cloud.automl_v1.types.ExportDataRequest, dict]):
                 The request object. Request message for
                 [AutoMl.ExportData][google.cloud.automl.v1.AutoMl.ExportData].
             name (str):
@@ -1080,7 +1081,7 @@ class AutoMlClient(metaclass=AutoMlClientMeta):
 
     def get_annotation_spec(
         self,
-        request: service.GetAnnotationSpecRequest = None,
+        request: Union[service.GetAnnotationSpecRequest, dict] = None,
         *,
         name: str = None,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
@@ -1090,7 +1091,7 @@ class AutoMlClient(metaclass=AutoMlClientMeta):
         r"""Gets an annotation spec.
 
         Args:
-            request (google.cloud.automl_v1.types.GetAnnotationSpecRequest):
+            request (Union[google.cloud.automl_v1.types.GetAnnotationSpecRequest, dict]):
                 The request object. Request message for
                 [AutoMl.GetAnnotationSpec][google.cloud.automl.v1.AutoMl.GetAnnotationSpec].
             name (str):
@@ -1149,7 +1150,7 @@ class AutoMlClient(metaclass=AutoMlClientMeta):
 
     def create_model(
         self,
-        request: service.CreateModelRequest = None,
+        request: Union[service.CreateModelRequest, dict] = None,
         *,
         parent: str = None,
         model: gca_model.Model = None,
@@ -1164,7 +1165,7 @@ class AutoMlClient(metaclass=AutoMlClientMeta):
         each annotation spec.
 
         Args:
-            request (google.cloud.automl_v1.types.CreateModelRequest):
+            request (Union[google.cloud.automl_v1.types.CreateModelRequest, dict]):
                 The request object. Request message for
                 [AutoMl.CreateModel][google.cloud.automl.v1.AutoMl.CreateModel].
             parent (str):
@@ -1244,7 +1245,7 @@ class AutoMlClient(metaclass=AutoMlClientMeta):
 
     def get_model(
         self,
-        request: service.GetModelRequest = None,
+        request: Union[service.GetModelRequest, dict] = None,
         *,
         name: str = None,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
@@ -1254,7 +1255,7 @@ class AutoMlClient(metaclass=AutoMlClientMeta):
         r"""Gets a model.
 
         Args:
-            request (google.cloud.automl_v1.types.GetModelRequest):
+            request (Union[google.cloud.automl_v1.types.GetModelRequest, dict]):
                 The request object. Request message for
                 [AutoMl.GetModel][google.cloud.automl.v1.AutoMl.GetModel].
             name (str):
@@ -1313,7 +1314,7 @@ class AutoMlClient(metaclass=AutoMlClientMeta):
 
     def list_models(
         self,
-        request: service.ListModelsRequest = None,
+        request: Union[service.ListModelsRequest, dict] = None,
         *,
         parent: str = None,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
@@ -1323,7 +1324,7 @@ class AutoMlClient(metaclass=AutoMlClientMeta):
         r"""Lists models.
 
         Args:
-            request (google.cloud.automl_v1.types.ListModelsRequest):
+            request (Union[google.cloud.automl_v1.types.ListModelsRequest, dict]):
                 The request object. Request message for
                 [AutoMl.ListModels][google.cloud.automl.v1.AutoMl.ListModels].
             parent (str):
@@ -1393,7 +1394,7 @@ class AutoMlClient(metaclass=AutoMlClientMeta):
 
     def delete_model(
         self,
-        request: service.DeleteModelRequest = None,
+        request: Union[service.DeleteModelRequest, dict] = None,
         *,
         name: str = None,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
@@ -1406,7 +1407,7 @@ class AutoMlClient(metaclass=AutoMlClientMeta):
         [metadata][google.longrunning.Operation.metadata] field.
 
         Args:
-            request (google.cloud.automl_v1.types.DeleteModelRequest):
+            request (Union[google.cloud.automl_v1.types.DeleteModelRequest, dict]):
                 The request object. Request message for
                 [AutoMl.DeleteModel][google.cloud.automl.v1.AutoMl.DeleteModel].
             name (str):
@@ -1488,7 +1489,7 @@ class AutoMlClient(metaclass=AutoMlClientMeta):
 
     def update_model(
         self,
-        request: service.UpdateModelRequest = None,
+        request: Union[service.UpdateModelRequest, dict] = None,
         *,
         model: gca_model.Model = None,
         update_mask: field_mask_pb2.FieldMask = None,
@@ -1499,7 +1500,7 @@ class AutoMlClient(metaclass=AutoMlClientMeta):
         r"""Updates a model.
 
         Args:
-            request (google.cloud.automl_v1.types.UpdateModelRequest):
+            request (Union[google.cloud.automl_v1.types.UpdateModelRequest, dict]):
                 The request object. Request message for
                 [AutoMl.UpdateModel][google.cloud.automl.v1.AutoMl.UpdateModel]
             model (google.cloud.automl_v1.types.Model):
@@ -1571,7 +1572,7 @@ class AutoMlClient(metaclass=AutoMlClientMeta):
 
     def deploy_model(
         self,
-        request: service.DeployModelRequest = None,
+        request: Union[service.DeployModelRequest, dict] = None,
         *,
         name: str = None,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
@@ -1595,7 +1596,7 @@ class AutoMlClient(metaclass=AutoMlClientMeta):
         completes.
 
         Args:
-            request (google.cloud.automl_v1.types.DeployModelRequest):
+            request (Union[google.cloud.automl_v1.types.DeployModelRequest, dict]):
                 The request object. Request message for
                 [AutoMl.DeployModel][google.cloud.automl.v1.AutoMl.DeployModel].
             name (str):
@@ -1677,7 +1678,7 @@ class AutoMlClient(metaclass=AutoMlClientMeta):
 
     def undeploy_model(
         self,
-        request: service.UndeployModelRequest = None,
+        request: Union[service.UndeployModelRequest, dict] = None,
         *,
         name: str = None,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
@@ -1695,7 +1696,7 @@ class AutoMlClient(metaclass=AutoMlClientMeta):
         completes.
 
         Args:
-            request (google.cloud.automl_v1.types.UndeployModelRequest):
+            request (Union[google.cloud.automl_v1.types.UndeployModelRequest, dict]):
                 The request object. Request message for
                 [AutoMl.UndeployModel][google.cloud.automl.v1.AutoMl.UndeployModel].
             name (str):
@@ -1777,7 +1778,7 @@ class AutoMlClient(metaclass=AutoMlClientMeta):
 
     def export_model(
         self,
-        request: service.ExportModelRequest = None,
+        request: Union[service.ExportModelRequest, dict] = None,
         *,
         name: str = None,
         output_config: io.ModelExportOutputConfig = None,
@@ -1795,7 +1796,7 @@ class AutoMlClient(metaclass=AutoMlClientMeta):
         completes.
 
         Args:
-            request (google.cloud.automl_v1.types.ExportModelRequest):
+            request (Union[google.cloud.automl_v1.types.ExportModelRequest, dict]):
                 The request object. Request message for
                 [AutoMl.ExportModel][google.cloud.automl.v1.AutoMl.ExportModel].
                 Models need to be enabled for exporting, otherwise an
@@ -1888,7 +1889,7 @@ class AutoMlClient(metaclass=AutoMlClientMeta):
 
     def get_model_evaluation(
         self,
-        request: service.GetModelEvaluationRequest = None,
+        request: Union[service.GetModelEvaluationRequest, dict] = None,
         *,
         name: str = None,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
@@ -1898,7 +1899,7 @@ class AutoMlClient(metaclass=AutoMlClientMeta):
         r"""Gets a model evaluation.
 
         Args:
-            request (google.cloud.automl_v1.types.GetModelEvaluationRequest):
+            request (Union[google.cloud.automl_v1.types.GetModelEvaluationRequest, dict]):
                 The request object. Request message for
                 [AutoMl.GetModelEvaluation][google.cloud.automl.v1.AutoMl.GetModelEvaluation].
             name (str):
@@ -1957,7 +1958,7 @@ class AutoMlClient(metaclass=AutoMlClientMeta):
 
     def list_model_evaluations(
         self,
-        request: service.ListModelEvaluationsRequest = None,
+        request: Union[service.ListModelEvaluationsRequest, dict] = None,
         *,
         parent: str = None,
         filter: str = None,
@@ -1968,7 +1969,7 @@ class AutoMlClient(metaclass=AutoMlClientMeta):
         r"""Lists model evaluations.
 
         Args:
-            request (google.cloud.automl_v1.types.ListModelEvaluationsRequest):
+            request (Union[google.cloud.automl_v1.types.ListModelEvaluationsRequest, dict]):
                 The request object. Request message for
                 [AutoMl.ListModelEvaluations][google.cloud.automl.v1.AutoMl.ListModelEvaluations].
             parent (str):
@@ -2059,6 +2060,19 @@ class AutoMlClient(metaclass=AutoMlClientMeta):
         # Done; return the response.
         return response
 
+    def __enter__(self):
+        return self
+
+    def __exit__(self, type, value, traceback):
+        """Releases underlying transport's resources.
+
+        .. warning::
+            ONLY use as a context manager if the transport is NOT shared
+            with other clients! Exiting the with block will CLOSE the transport
+            and may cause errors in other clients!
+        """
+        self.transport.close()
+
 
 try:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
