@@ -17,7 +17,7 @@ from collections import OrderedDict
 from distutils import util
 import os
 import re
-from typing import Callable, Dict, Optional, Sequence, Tuple, Type, Union
+from typing import Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core import client_options as client_options_lib  # type: ignore
@@ -355,11 +355,12 @@ class PredictionServiceClient(metaclass=PredictionServiceClientMeta):
                 client_cert_source_for_mtls=client_cert_source_func,
                 quota_project_id=client_options.quota_project_id,
                 client_info=client_info,
+                always_use_jwt_access=True,
             )
 
     def predict(
         self,
-        request: prediction_service.PredictRequest = None,
+        request: Union[prediction_service.PredictRequest, dict] = None,
         *,
         name: str = None,
         payload: data_items.ExamplePayload = None,
@@ -391,7 +392,7 @@ class PredictionServiceClient(metaclass=PredictionServiceClientMeta):
            UTF-8 encoded.
 
         Args:
-            request (google.cloud.automl_v1beta1.types.PredictRequest):
+            request (Union[google.cloud.automl_v1beta1.types.PredictRequest, dict]):
                 The request object. Request message for
                 [PredictionService.Predict][google.cloud.automl.v1beta1.PredictionService.Predict].
             name (str):
@@ -492,7 +493,7 @@ class PredictionServiceClient(metaclass=PredictionServiceClientMeta):
 
     def batch_predict(
         self,
-        request: prediction_service.BatchPredictRequest = None,
+        request: Union[prediction_service.BatchPredictRequest, dict] = None,
         *,
         name: str = None,
         input_config: io.BatchPredictInputConfig = None,
@@ -521,7 +522,7 @@ class PredictionServiceClient(metaclass=PredictionServiceClientMeta):
         -  Tables
 
         Args:
-            request (google.cloud.automl_v1beta1.types.BatchPredictRequest):
+            request (Union[google.cloud.automl_v1beta1.types.BatchPredictRequest, dict]):
                 The request object. Request message for
                 [PredictionService.BatchPredict][google.cloud.automl.v1beta1.PredictionService.BatchPredict].
             name (str):
@@ -701,6 +702,19 @@ class PredictionServiceClient(metaclass=PredictionServiceClientMeta):
         # Done; return the response.
         return response
 
+    def __enter__(self):
+        return self
+
+    def __exit__(self, type, value, traceback):
+        """Releases underlying transport's resources.
+
+        .. warning::
+            ONLY use as a context manager if the transport is NOT shared
+            with other clients! Exiting the with block will CLOSE the transport
+            and may cause errors in other clients!
+        """
+        self.transport.close()
+
 
 try:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
