@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,10 +13,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 import proto  # type: ignore
 
-
 from google.cloud.automl_v1beta1.types import io
 
 
@@ -73,21 +70,15 @@ class TableSpec(proto.Message):
             happens.
     """
 
-    name = proto.Field(proto.STRING, number=1)
-
-    time_column_spec_id = proto.Field(proto.STRING, number=2)
-
-    row_count = proto.Field(proto.INT64, number=3)
-
-    valid_row_count = proto.Field(proto.INT64, number=4)
-
-    column_count = proto.Field(proto.INT64, number=7)
-
+    name = proto.Field(proto.STRING, number=1,)
+    time_column_spec_id = proto.Field(proto.STRING, number=2,)
+    row_count = proto.Field(proto.INT64, number=3,)
+    valid_row_count = proto.Field(proto.INT64, number=4,)
+    column_count = proto.Field(proto.INT64, number=7,)
     input_configs = proto.RepeatedField(
         proto.MESSAGE, number=5, message=io.InputConfig,
     )
-
-    etag = proto.Field(proto.STRING, number=6)
+    etag = proto.Field(proto.STRING, number=6,)
 
 
 __all__ = tuple(sorted(__protobuf__.manifest))
